@@ -1,4 +1,3 @@
-import json
 import os
 import plistlib
 import threading
@@ -252,10 +251,12 @@ class InstrumentsBase:
         applist = self.instruments.call(InstrumentsService.ApplicationListing,
                                         "installedApplicationsMatching:registerUpdateToken:",
                                         {}, "").selector
-        if bundle_id:
+        if bundle_id is not None:
             for app in applist:
                 if app.get('CFBundleIdentifier') == bundle_id:
                     return app
+            else:
+                return None
         return applist
 
     def sysmontap(self,
@@ -279,9 +280,11 @@ class InstrumentsBase:
             'cpuUsage': True,
             'sampleInterval': time * 1000000}
         _system_attributes = self.system_attributes or system_attributes
-        config['sysAttrs'] = _system_attributes
+        if _system_attributes:
+            config['sysAttrs'] = _system_attributes
         process_attributes = self.process_attributes or process_attributes
-        config['procAttrs'] = process_attributes
+        if process_attributes:
+            config['procAttrs'] = process_attributes
         self.instruments.call(InstrumentsService.Sysmontap, "setConfig:", config)
         self.instruments.register_channel_callback(InstrumentsService.Sysmontap, callback)
         self.instruments.call(InstrumentsService.Sysmontap, "start")
@@ -370,15 +373,17 @@ class InstrumentsBase:
 
     def core_profile_session(self,
                              callback: callable,
-                             stopSignal: threading.Event = threading.Event()):
+                             stopSignal: threading.Event = threading.Event(),
+                             config=None):
+        if config is None:
+            config = {'rp': 10,
+                      'tc': [{'kdf2': {630784000, 833617920, 830472456},
+                              'tk': 3,
+                              'uuid': str(uuid.uuid4()).upper()}],
+                      'ur': 500}
         self.instruments.register_channel_callback(InstrumentsService.CoreProfileSessionTap,
                                                    callback)
-        self.instruments.call(InstrumentsService.CoreProfileSessionTap, "setConfig:",
-                              {'rp': 10,
-                               'tc': [{'kdf2': {630784000, 833617920, 830472456},
-                                       'tk': 3,
-                                       'uuid': str(uuid.uuid4()).upper()}],
-                               'ur': 500})
+        self.instruments.call(InstrumentsService.CoreProfileSessionTap, "setConfig:", config)
         self.instruments.call(InstrumentsService.CoreProfileSessionTap, "start")
         while not stopSignal.wait(1):
             pass
@@ -401,7 +406,7 @@ class InstrumentsBase:
                               "configureCounters:counterProfile:interval:windowLimit:tracingPID:",
                               RawInt64sl(min_collection_interval, 3, 1, 0), RawInt32sl(-1))
         self.instruments.call(InstrumentsService.GPU, 'startCollectingCounters')
-        log.info('Wait for gup counters data ...')
+        log.info('Wait for gpu counters data ...')
         while not stopSignal.wait(1):
             pass
         self.instruments.call(InstrumentsService.GPU, 'stopCollectingCounters')
