@@ -6,6 +6,7 @@ import uuid
 from copy import deepcopy
 from datetime import datetime
 from distutils.version import LooseVersion
+from statistics import mean
 
 import click
 
@@ -15,7 +16,9 @@ from ios_device.util import Log, api_util
 from ios_device.util.exceptions import InstrumentRPCParseError
 from ios_device.util.gpu_decode import JSEvn, TraceData, GRCDecodeOrder, GRCDisplayOrder
 from ios_device.util.kc_data import kc_data_parse
-from ios_device.util.utils import DumpDisk, DumpNetwork, DumpMemory, convertBytes
+from ios_device.util.kperf_data import kdbg_extract_all
+from ios_device.util.utils import DumpDisk, DumpNetwork, DumpMemory, convertBytes, \
+    MOVIE_FRAME_COST, NANO_SECOND, kperf_data
 from ios_device.util.variables import LOG, InstrumentsService
 
 log = Log.getLogger(LOG.Instrument.value)
@@ -158,7 +161,7 @@ def cmd_networking(udid, network, format):
 @click.option('-b', '--bundle_id', required=True, help='Process app bundleId to filter')
 def cmd_appmonitor(udid, network, format, time, bundle_id):
     """ Get application performance data """
-    proc_filter = ['Pid','Name', 'CPU', 'Memory','DiskReads','DiskWrites','Threads']
+    proc_filter = ['Pid', 'Name', 'CPU', 'Memory', 'DiskReads', 'DiskWrites', 'Threads']
     process_attributes = dataclasses.make_dataclass('SystemProcessAttributes', proc_filter)
     ios_version = 0
 
@@ -182,8 +185,8 @@ def cmd_appmonitor(udid, network, format, time, bundle_id):
 
     with InstrumentsBase(udid=udid, network=network) as rpc:
         ios_version = rpc.lockdown.ios_version
-        rpc.process_attributes = ['pid','name', 'cpuUsage', 'physFootprint',
-                                  'diskBytesRead','diskBytesWritten','threadCount']
+        rpc.process_attributes = ['pid', 'name', 'cpuUsage', 'physFootprint',
+                                  'diskBytesRead', 'diskBytesWritten', 'threadCount']
         if bundle_id:
             app = rpc.application_listing(bundle_id)
             if not app:
@@ -361,6 +364,61 @@ def cmd_graphics(udid, network, format, time):
         rpc.graphics(on_callback_message, time)
 
 
+@instruments.command('display', cls=Command)
+def cmd_display(udid, network, format):
+    """ Get graphics fps
+    """
+    last_frame = None
+    last_1_frame_cost, last_2_frame_cost, last_3_frame_cost = 0, 0, 0
+    jank_count = 0
+    big_jank_count = 0
+    jank_time_count = 0
+    mach_time_factor = 125 / 3
+    frame_count = 0
+    time_count = 0
+    last_time = datetime.now().timestamp()
+    _list = []
+
+    def on_graphics_message(res):
+        nonlocal frame_count, last_frame, last_1_frame_cost, last_2_frame_cost, last_3_frame_cost, time_count, mach_time_factor, last_time, \
+            jank_count, big_jank_count, jank_time_count, _list
+        if type(res.selector) is InstrumentRPCParseError:
+            for args in kperf_data(res.selector.data):
+                _time, code = args[0], args[7]
+                if kdbg_extract_all(code) == (0x31, 0x80, 0xc6):
+                    if not last_frame:
+                        last_frame = _time
+                    else:
+                        this_frame_cost = (_time - last_frame) * mach_time_factor
+                        if all([last_3_frame_cost != 0, last_2_frame_cost != 0, last_1_frame_cost != 0]):
+                            if this_frame_cost > mean([last_3_frame_cost, last_2_frame_cost, last_1_frame_cost]) * 2 \
+                                    and this_frame_cost > MOVIE_FRAME_COST * NANO_SECOND * 2:
+                                jank_count += 1
+                                jank_time_count += this_frame_cost
+                                if this_frame_cost > mean(
+                                        [last_3_frame_cost, last_2_frame_cost, last_1_frame_cost]) * 3 \
+                                        and this_frame_cost > MOVIE_FRAME_COST * NANO_SECOND * 3:
+                                    big_jank_count += 1
+
+                        last_3_frame_cost, last_2_frame_cost, last_1_frame_cost = last_2_frame_cost, last_1_frame_cost, this_frame_cost
+                        time_count += this_frame_cost
+                        last_frame = _time
+                        frame_count += 1
+
+                if time_count > NANO_SECOND:
+                    print(
+                        {"time": datetime.now().timestamp() - last_time, "fps": frame_count / time_count * NANO_SECOND,
+                         "jank": jank_count, "big_jank": big_jank_count, "stutter": jank_time_count / time_count})
+                    jank_count = 0
+                    big_jank_count = 0
+                    jank_time_count = 0
+                    frame_count = 0
+                    time_count = 0
+
+    with InstrumentsBase(udid=udid, network=network) as rpc:
+        rpc.core_profile_session(on_graphics_message)
+
+
 @instruments.command('notifications', cls=Command)
 def cmd_notifications(udid, network, format):
     """Get mobile notifications
@@ -440,7 +498,7 @@ def gpu_counters(udid, network, format):
         def dropped_message(res):
             nonlocal js_env, decode_key_list, display_key_list
             if res.selector[0] == 1:
-                js_env.dump_trace(TraceData(*res.selector))
+                js_env.dump_trace(TraceData(*res.selector[:6]))
             elif res.selector[0] == 0:
                 _data = res.selector[4]
                 decode_key_list = GRCDecodeOrder.decode(_data.get(1))
@@ -450,7 +508,7 @@ def gpu_counters(udid, network, format):
         machTimeInfo = rpc.device_info.machTimeInfo()
         mach_time_factor = machTimeInfo[1] / machTimeInfo[2]
         data = rpc.gpu_counters(callback=dropped_message, stopSignal=stopSignal)
-        js_env.dump_trace(TraceData(*data[0]))
+        js_env.dump_trace(TraceData(*data[0][:6]))
 
 
 @instruments.command('app_lifecycle', cls=Command)
