@@ -2,24 +2,17 @@
 @Date    : 2021-01-28
 @Author  : liyachao
 """
-import json
-import time
 import uuid
 from datetime import datetime
 
-from ios_device.util.forward import ForwardPorts
-from ios_device.util.lockdown import LockdownClient
-
-from ios_device.util.dtxlib import get_auxiliary_text
-from numpy import long, mean
-
-from ios_device.servers.DTXSever import InstrumentRPCParseError
-
-from ios_device.servers.Installation import InstallationProxy
 
+from ios_device.util.exceptions import InstrumentRPCParseError
+from ios_device.servers.Installation import InstallationProxyService
 from ios_device.servers.Instrument import InstrumentServer
 from ios_device.util import api_util
 from ios_device.util.api_util import PyIOSDeviceException, RunXCUITest
+from ios_device.util.forward import ForwardPorts
+from ios_device.util.kperf_data import KperfData
 from ios_device.util.utils import kperf_data
 
 
@@ -118,7 +111,7 @@ class PyiOSDevice:
         """
         return get_applications(device_id=self.device_id, rpc_channel=self.rpc_channel)
 
-    def start_xcuitest(self, bundle_id, callback: callable, app_env: dict = None, forward: bool = False,
+    def start_xcuitest(self, bundle_id, callback: callable, app_env: dict = None,
                        pair_ports=None):
         """
         启动 xcuittest
@@ -130,7 +123,7 @@ class PyiOSDevice:
         :return:
         """
 
-        self.xcuitest = start_xcuitest(bundle_id, callback, self.device_id, app_env, forward, pair_ports)
+        self.xcuitest = start_xcuitest(bundle_id, callback, self.device_id, app_env, pair_ports)
         return self.xcuitest
 
     def stop_xcuitest(self, xcuitest=None):
@@ -222,7 +215,7 @@ def get_processes(device_id: str = None, rpc_channel: InstrumentServer = None):
         _rpc_channel = init(device_id)
     else:
         _rpc_channel = rpc_channel
-    running = _rpc_channel.call("com.apple.instruments.server.services.deviceinfo", "runningProcesses").parsed
+    running = _rpc_channel.call("com.apple.instruments.server.services.deviceinfo", "runningProcesses").selector
     if not rpc_channel:
         _rpc_channel.stop()
     return running
@@ -302,7 +295,7 @@ def launch_app(bundle_id: str, device_id: str = None, rpc_channel: InstrumentSer
     _rpc_channel.register_channel_callback(channel_name, lambda x: x)
     pid = _rpc_channel.call(channel_name,
                             "launchSuspendedProcessWithDevicePath:bundleIdentifier:environment:arguments:options:", "",
-                            bundle_id, {}, [], {"StartSuspendedKey": 0, "KillExisting": 1}).parsed
+                            bundle_id, {}, [], {"StartSuspendedKey": 0, "KillExisting": 1}).selector
     if not rpc_channel:
         _rpc_channel.stop()
     return pid
@@ -359,7 +352,7 @@ def start_get_system(device_id: str = None, rpc_channel: InstrumentServer = None
     def _callback(res):
         api_util.system_caller(res, callback)
 
-    _rpc_channel.register_unhandled_callback(lambda x: x)
+    _rpc_channel.register_undefined_callback(lambda x: x)
     _rpc_channel.call("com.apple.instruments.server.services.sysmontap", "setConfig:", {
         'ur': 1000,  # 输出频率 ms
         'bm': 0,
@@ -398,7 +391,7 @@ def get_device(device_id: str = None, rpc_channel: InstrumentServer = None):
     :param rpc_channel:
     :return:
     """
-    current_device = InstallationProxy(udid=device_id, lockdown=rpc_channel.lockdown if rpc_channel else None)
+    current_device = InstallationProxyService(udid=device_id, lockdown=rpc_channel.lockdown if rpc_channel else None)
     return current_device
 
 
@@ -416,18 +409,17 @@ def get_applications(device_id: str = None, rpc_channel: InstrumentServer = None
     application_list = _rpc_channel.call(
         "com.apple.instruments.server.services.device.applictionListing",
         "installedApplicationsMatching:registerUpdateToken:",
-        {}, "").parsed
+        {}, "").selector
     if not rpc_channel:
         _rpc_channel.stop()
     return application_list
 
 
 def start_xcuitest(bundle_id: str, callback: callable, device_id: str = None, app_env: dict = None,
-                   forward: bool = False, pair_ports=None):
+                   pair_ports=None):
     """
     启动 xcuittest
     :param pair_ports: 端口对的数组，每对端口中前一个代表远程端口，后一个代表本地端口，例如：["8100:8100", "8200:8200"]
-    :param forward: 是否进行端口转发
     :param bundle_id:
     :param callback:
     :param device_id:
@@ -450,7 +442,7 @@ def start_xcuitest(bundle_id: str, callback: callable, device_id: str = None, ap
     if pair_ports is None:
         pair_ports = ["8100:8100"]
     xcuitest = RunXCUITest(bundle_id=bundle_id, callback=callback, device_id=device_id, app_env=app_env,
-                           forward=forward, pair_ports=pair_ports)
+                           pair_ports=pair_ports)
 
     xcuitest.start()
     return xcuitest
@@ -469,6 +461,7 @@ def stop_xcuitest(xcuitest):
 
 
 def start_get_fps(device_id: str = None, rpc_channel: InstrumentServer = None, callback: callable = None):
+    from statistics import mean
     """
     开始获取 fps 相关数据
     :param device_id:
@@ -500,14 +493,14 @@ def start_get_fps(device_id: str = None, rpc_channel: InstrumentServer = None, c
     def _callback(res):
         nonlocal frame_count, last_frame, last_1_frame_cost, last_2_frame_cost, last_3_frame_cost, time_count, mach_time_factor, \
             jank_count, big_jank_count, jank_time_count, _list, count_time
-        if type(res.plist) is InstrumentRPCParseError:
-            for args in kperf_data(res.raw.get_selector()):
+        if type(res.selector) is InstrumentRPCParseError:
+            for args in kperf_data(res.selector.data):
                 _time, code = args[0], args[7]
                 if code == 830472984:
                     if not last_frame:
-                        last_frame = long(_time)
+                        last_frame = _time
                     else:
-                        this_frame_cost = (long(_time) - last_frame) * mach_time_factor
+                        this_frame_cost = (_time - last_frame) * mach_time_factor
                         if all([last_3_frame_cost != 0, last_2_frame_cost != 0, last_1_frame_cost != 0]):
                             if this_frame_cost > mean([last_3_frame_cost, last_2_frame_cost, last_1_frame_cost]) * 2 \
                                     and this_frame_cost > MOVIE_FRAME_COST * NANO_SECOND * 2:
@@ -520,10 +513,10 @@ def start_get_fps(device_id: str = None, rpc_channel: InstrumentServer = None, c
 
                         last_3_frame_cost, last_2_frame_cost, last_1_frame_cost = last_2_frame_cost, last_1_frame_cost, this_frame_cost
                         time_count += this_frame_cost
-                        last_frame = long(_time)
+                        last_frame = _time
                         frame_count += 1
-                else:
-                    time_count = (datetime.now().timestamp() - count_time) * NANO_SECOND
+                # else:
+                #     time_count = (datetime.now().timestamp() - count_time) * NANO_SECOND
                 if time_count > NANO_SECOND:
                     callback(
                         {"currentTime": str(datetime.now()), "FPS": frame_count / time_count * NANO_SECOND,
@@ -536,9 +529,10 @@ def start_get_fps(device_id: str = None, rpc_channel: InstrumentServer = None, c
                     time_count = 0
                     count_time = datetime.now().timestamp()
 
-    _rpc_channel.register_unhandled_callback(lambda x: x)
+    Kperf = KperfData()
+    _rpc_channel.register_undefined_callback(lambda x: x)
     # 获取mach time比例
-    mach_time_info = _rpc_channel.call("com.apple.instruments.server.services.deviceinfo", "machTimeInfo").parsed
+    mach_time_info = _rpc_channel.call("com.apple.instruments.server.services.deviceinfo", "machTimeInfo").selector
     mach_time_factor = mach_time_info[1] / mach_time_info[2]
     _rpc_channel.register_channel_callback("com.apple.instruments.server.services.coreprofilesessiontap",
                                            _callback)
@@ -578,7 +572,7 @@ def get_energy(pid: int, device_id: str = None, rpc_channel: InstrumentServer =
     ret = _rpc_channel.call(channel_name, "sampleAttributes:forPIDs:", attr, {pid})
     if not rpc_channel:
         _rpc_channel.stop()
-    return ret.parsed
+    return ret.selector
 
 
 def start_get_graphics_fps(device_id: str = None, rpc_channel: InstrumentServer = None, callback: callable = None):
@@ -595,10 +589,10 @@ def start_get_graphics_fps(device_id: str = None, rpc_channel: InstrumentServer
         _rpc_channel = rpc_channel
 
     def _callback(res):
-        data = res.parsed
+        data = res.selector
         callback({"currentTime": str(datetime.now()), "fps": data['CoreAnimationFramesPerSecond']})
 
-    _rpc_channel.register_unhandled_callback(lambda x: x)
+    _rpc_channel.register_undefined_callback(lambda x: x)
     _rpc_channel.register_channel_callback("com.apple.instruments.server.services.graphics.opengl", _callback)
     _rpc_channel.call("com.apple.instruments.server.services.graphics.opengl", "startSamplingAtTimeInterval:", 0.0)
     return _rpc_channel
@@ -630,9 +624,9 @@ def start_get_mobile_notifications(device_id: str = None, rpc_channel: Instrumen
         _rpc_channel = rpc_channel
 
     def _callback(res):
-        callback(get_auxiliary_text(res.raw))
+        callback(res)
 
-    _rpc_channel.register_unhandled_callback(_callback)
+    _rpc_channel.register_channel_callback("com.apple.instruments.server.services.mobilenotifications", _callback)
 
     _rpc_channel.call(
         "com.apple.instruments.server.services.mobilenotifications",
@@ -648,7 +642,7 @@ def stop_get_mobile_notifications(rpc_channel: InstrumentServer):
     """
     rpc_channel.call(
         "com.apple.instruments.server.services.mobilenotifications",
-        'setApplicationStateNotificationsEnabled:', str(True))
+        'setApplicationStateNotificationsEnabled:', str(False))
 
 
 def get_netstat(pid: int, device_id: str = None, rpc_channel: InstrumentServer = None):
@@ -666,8 +660,8 @@ def get_netstat(pid: int, device_id: str = None, rpc_channel: InstrumentServer =
         _rpc_channel = rpc_channel
     channel = "com.apple.xcode.debug-gauge-data-providers.NetworkStatistics"
     attr = {}
-    # print("start", _rpc_channel.call(channel, "startSamplingForPIDs:", {pid}).parsed)
-    ret = _rpc_channel.call(channel, "sampleAttributes:forPIDs:", attr, {pid}).parsed
+    # print("start", _rpc_channel.call(channel, "startSamplingForPIDs:", {pid}).selector)
+    ret = _rpc_channel.call(channel, "sampleAttributes:forPIDs:", attr, {pid}).selector
     if not rpc_channel:
         _rpc_channel.stop()
     return ret
@@ -689,79 +683,3 @@ def start_forward(pair_ports=None, device_id: str = None):
 
 def stop_forward(forward: ForwardPorts):
     forward.stop()
-
-
-def te1st(res):
-    # print(res[0]["PerCPUUsage"])
-    print(res)
-
-
-if __name__ == "__main__":
-    # print(get_netstat(216))
-    # channel = PyiOSDevice()
-    # print(channel.get_netstat(216))
-    # channel.stop()
-    # c = start_get_mobile_notifications(callback=te1st)
-    # time.sleep(5)
-    # stop_get_mobile_notifications(c)
-    # time.sleep(3)
-    # print("asdasdasd")
-    # c.stop()
-
-    # channel = start_get_fps(callback=te1st)
-    # time.sleep(10)
-    # stop_get_fps(channel)
-    # channel.stop()
-
-    # x = start_xcuitest("cn.rongcloud.rce.autotest.xctrunner", te1st,app_env={'USE_PORT': '8111'})
-    # time.sleep(10)
-    # stop_xcuitest(x)
-
-    # system = start_get_system(callback=te1st)
-    # time.sleep(10)
-    # stop_get_system(system)
-    # processes = channel.start_get_gpu_data(callba)
-    # print(processes)
-    # channel.stop_channel()
-
-    # 有开始 有结束的demo
-    # channel = init()
-    # start_get_network(rpc_channel=channel, callback=te1st)
-    # time.sleep(10)
-    # stop_get_network(rpc_channel=channel)
-    # channel.stop()
-
-    # 普通的demo
-    # channel = get_channel()
-    # print(channel)
-    # get_device()
-
-    # channel = PyiOSDevice()
-    # print(channel.get_channel())
-
-    # channel = start_get_power_data(callback=test)
-    # # time.sleep(10)
-    # # stop_get_system_data(channel)
-    # channel.stop()
-
-    # device = get_device()
-    # print(device.get_apps_bid())
-
-    f = start_forward(["8200:8200"])
-    time.sleep(30)
-    stop_forward(f)
-    pass
-
-    # channel.register_unhandled_callback(test)
-    # channel.register_callback("_notifyOfPublishedCapabilities:", lambda a: print(1))
-    # start_get_gpu_data(rpc_channel=channel, callback=test)
-    # time.sleep(2)
-    # stop_get_gpurpc_channel=channel,_data(channel)
-    # channel.get_processes()
-    # process = channel.get_processes()
-    # print(process)
-    # channel.start_activity(242)
-    # print(get_channel(rpc_channel=channel))
-    # dc = channel.get_processes()
-    # print(dc)
-    # channel.stop_channel()
