@@ -36,87 +36,87 @@ from construct import Const, Int64ul
 from cmd import Cmd
 from six import PY3
 from pprint import pprint
+
+from ..remote.remote_lockdown import RemoteLockdownClient
 from ..util import hexdump
 
 from ..util.lockdown import LockdownClient
 
+MODEMASK = 0o0000777
 
-MODEMASK =  0o0000777
+AFC_OP_STATUS = 0x00000001
+AFC_OP_DATA = 0x00000002  # Data */
+AFC_OP_READ_DIR = 0x00000003  # ReadDir */
+AFC_OP_READ_FILE = 0x00000004  # ReadFile */
+AFC_OP_WRITE_FILE = 0x00000005  # WriteFile */
+AFC_OP_WRITE_PART = 0x00000006  # WritePart */
+AFC_OP_TRUNCATE = 0x00000007  # TruncateFile */
+AFC_OP_REMOVE_PATH = 0x00000008  # RemovePath */
+AFC_OP_MAKE_DIR = 0x00000009  # MakeDir */
+AFC_OP_GET_FILE_INFO = 0x0000000a  # GetFileInfo */
+AFC_OP_GET_DEVINFO = 0x0000000b  # GetDeviceInfo */
+AFC_OP_WRITE_FILE_ATOM = 0x0000000c  # WriteFileAtomic (tmp file+rename) */
+AFC_OP_FILE_OPEN = 0x0000000d  # FileRefOpen */
+AFC_OP_FILE_OPEN_RES = 0x0000000e  # FileRefOpenResult */
+AFC_OP_READ = 0x0000000f  # FileRefRead */
+AFC_OP_WRITE = 0x00000010  # FileRefWrite */
+AFC_OP_FILE_SEEK = 0x00000011  # FileRefSeek */
+AFC_OP_FILE_TELL = 0x00000012  # FileRefTell */
+AFC_OP_FILE_TELL_RES = 0x00000013  # FileRefTellResult */
+AFC_OP_FILE_CLOSE = 0x00000014  # FileRefClose */
+AFC_OP_FILE_SET_SIZE = 0x00000015  # FileRefSetFileSize (ftruncate) */
+AFC_OP_GET_CON_INFO = 0x00000016  # GetConnectionInfo */
+AFC_OP_SET_CON_OPTIONS = 0x00000017  # SetConnectionOptions */
+AFC_OP_RENAME_PATH = 0x00000018  # RenamePath */
+AFC_OP_SET_FS_BS = 0x00000019  # SetFSBlockSize (0x800000) */
+AFC_OP_SET_SOCKET_BS = 0x0000001A  # SetSocketBlockSize (0x800000) */
+AFC_OP_FILE_LOCK = 0x0000001B  # FileRefLock */
+AFC_OP_MAKE_LINK = 0x0000001C  # MakeLink */
+AFC_OP_SET_FILE_TIME = 0x0000001E  # set st_mtime */
 
-AFC_OP_STATUS          = 0x00000001
-AFC_OP_DATA            = 0x00000002    #Data */
-AFC_OP_READ_DIR        = 0x00000003    #ReadDir */
-AFC_OP_READ_FILE       = 0x00000004    #ReadFile */
-AFC_OP_WRITE_FILE      = 0x00000005    #WriteFile */
-AFC_OP_WRITE_PART      = 0x00000006    #WritePart */
-AFC_OP_TRUNCATE        = 0x00000007    #TruncateFile */
-AFC_OP_REMOVE_PATH     = 0x00000008    #RemovePath */
-AFC_OP_MAKE_DIR        = 0x00000009    #MakeDir */
-AFC_OP_GET_FILE_INFO   = 0x0000000a    #GetFileInfo */
-AFC_OP_GET_DEVINFO     = 0x0000000b    #GetDeviceInfo */
-AFC_OP_WRITE_FILE_ATOM = 0x0000000c    #WriteFileAtomic (tmp file+rename) */
-AFC_OP_FILE_OPEN       = 0x0000000d    #FileRefOpen */
-AFC_OP_FILE_OPEN_RES   = 0x0000000e    #FileRefOpenResult */
-AFC_OP_READ            = 0x0000000f    #FileRefRead */
-AFC_OP_WRITE           = 0x00000010    #FileRefWrite */
-AFC_OP_FILE_SEEK       = 0x00000011    #FileRefSeek */
-AFC_OP_FILE_TELL       = 0x00000012    #FileRefTell */
-AFC_OP_FILE_TELL_RES   = 0x00000013    #FileRefTellResult */
-AFC_OP_FILE_CLOSE      = 0x00000014    #FileRefClose */
-AFC_OP_FILE_SET_SIZE   = 0x00000015    #FileRefSetFileSize (ftruncate) */
-AFC_OP_GET_CON_INFO    = 0x00000016    #GetConnectionInfo */
-AFC_OP_SET_CON_OPTIONS = 0x00000017    #SetConnectionOptions */
-AFC_OP_RENAME_PATH     = 0x00000018    #RenamePath */
-AFC_OP_SET_FS_BS       = 0x00000019    #SetFSBlockSize (0x800000) */
-AFC_OP_SET_SOCKET_BS   = 0x0000001A    #SetSocketBlockSize (0x800000) */
-AFC_OP_FILE_LOCK       = 0x0000001B    #FileRefLock */
-AFC_OP_MAKE_LINK       = 0x0000001C    #MakeLink */
-AFC_OP_SET_FILE_TIME   = 0x0000001E    #set st_mtime */
+AFC_E_SUCCESS = 0
+AFC_E_UNKNOWN_ERROR = 1
+AFC_E_OP_HEADER_INVALID = 2
+AFC_E_NO_RESOURCES = 3
+AFC_E_READ_ERROR = 4
+AFC_E_WRITE_ERROR = 5
+AFC_E_UNKNOWN_PACKET_TYPE = 6
+AFC_E_INVALID_ARG = 7
+AFC_E_OBJECT_NOT_FOUND = 8
+AFC_E_OBJECT_IS_DIR = 9
+AFC_E_PERM_DENIED = 10
+AFC_E_SERVICE_NOT_CONNECTED = 11
+AFC_E_OP_TIMEOUT = 12
+AFC_E_TOO_MUCH_DATA = 13
+AFC_E_END_OF_DATA = 14
+AFC_E_OP_NOT_SUPPORTED = 15
+AFC_E_OBJECT_EXISTS = 16
+AFC_E_OBJECT_BUSY = 17
+AFC_E_NO_SPACE_LEFT = 18
+AFC_E_OP_WOULD_BLOCK = 19
+AFC_E_IO_ERROR = 20
+AFC_E_OP_INTERRUPTED = 21
+AFC_E_OP_IN_PROGRESS = 22
+AFC_E_INTERNAL_ERROR = 23
 
-AFC_E_SUCCESS                = 0
-AFC_E_UNKNOWN_ERROR          = 1
-AFC_E_OP_HEADER_INVALID      = 2
-AFC_E_NO_RESOURCES           = 3
-AFC_E_READ_ERROR             = 4
-AFC_E_WRITE_ERROR            = 5
-AFC_E_UNKNOWN_PACKET_TYPE    = 6
-AFC_E_INVALID_ARG            = 7
-AFC_E_OBJECT_NOT_FOUND       = 8
-AFC_E_OBJECT_IS_DIR          = 9
-AFC_E_PERM_DENIED            =10
-AFC_E_SERVICE_NOT_CONNECTED  =11
-AFC_E_OP_TIMEOUT             =12
-AFC_E_TOO_MUCH_DATA          =13
-AFC_E_END_OF_DATA            =14
-AFC_E_OP_NOT_SUPPORTED       =15
-AFC_E_OBJECT_EXISTS          =16
-AFC_E_OBJECT_BUSY            =17
-AFC_E_NO_SPACE_LEFT          =18
-AFC_E_OP_WOULD_BLOCK         =19
-AFC_E_IO_ERROR               =20
-AFC_E_OP_INTERRUPTED         =21
-AFC_E_OP_IN_PROGRESS         =22
-AFC_E_INTERNAL_ERROR         =23
+AFC_E_MUX_ERROR = 30
+AFC_E_NO_MEM = 31
+AFC_E_NOT_ENOUGH_DATA = 32
+AFC_E_DIR_NOT_EMPTY = 33
 
-AFC_E_MUX_ERROR              =30
-AFC_E_NO_MEM                 =31
-AFC_E_NOT_ENOUGH_DATA        =32
-AFC_E_DIR_NOT_EMPTY          =33
-
-AFC_FOPEN_RDONLY   = 0x00000001 #/**< r   O_RDONLY */
-AFC_FOPEN_RW       = 0x00000002 #/**< r+  O_RDWR   | O_CREAT */
-AFC_FOPEN_WRONLY   = 0x00000003 #/**< w   O_WRONLY | O_CREAT  | O_TRUNC */
-AFC_FOPEN_WR       = 0x00000004 #/**< w+  O_RDWR   | O_CREAT  | O_TRUNC */
-AFC_FOPEN_APPEND   = 0x00000005 #/**< a   O_WRONLY | O_APPEND | O_CREAT */
-AFC_FOPEN_RDAPPEND = 0x00000006 #/**< a+  O_RDWR   | O_APPEND | O_CREAT */
+AFC_FOPEN_RDONLY = 0x00000001  # /**< r   O_RDONLY */
+AFC_FOPEN_RW = 0x00000002  # /**< r+  O_RDWR   | O_CREAT */
+AFC_FOPEN_WRONLY = 0x00000003  # /**< w   O_WRONLY | O_CREAT  | O_TRUNC */
+AFC_FOPEN_WR = 0x00000004  # /**< w+  O_RDWR   | O_CREAT  | O_TRUNC */
+AFC_FOPEN_APPEND = 0x00000005  # /**< a   O_WRONLY | O_APPEND | O_CREAT */
+AFC_FOPEN_RDAPPEND = 0x00000006  # /**< a+  O_RDWR   | O_APPEND | O_CREAT */
 
 AFC_HARDLINK = 1
 AFC_SYMLINK = 2
 
-AFC_LOCK_SH = 1 | 4  #/**< shared lock */
-AFC_LOCK_EX = 2 | 4  #/**< exclusive lock */
-AFC_LOCK_UN = 8 | 4  #/**< unlock */
-
+AFC_LOCK_SH = 1 | 4  # /**< shared lock */
+AFC_LOCK_EX = 2 | 4  # /**< exclusive lock */
+AFC_LOCK_UN = 8 | 4  # /**< unlock */
 
 if PY3:
     AFCMAGIC = b"CFA6LPAA"
@@ -133,11 +133,18 @@ AFCPacket = Struct(
 
 
 class AFCClient(object):
+    SERVICE_NAME = 'com.apple.afc'
+    RSD_SERVICE_NAME = 'com.apple.afc.shim.remote'
+
     def __init__(self, lockdown=None, serviceName="com.apple.afc", service=None, udid=None, logger=None):
         self.logger = logger or logging.getLogger(__name__)
         self.serviceName = serviceName
-        self.lockdown = lockdown or LockdownClient(udid=udid)
-        self.service = service if service else self.lockdown.start_service(self.serviceName)
+        if not service:
+            self.lockdown = lockdown or LockdownClient(udid=udid)
+            SERVICE_NAME = self.RSD_SERVICE_NAME if isinstance(self.lockdown,
+                                                               RemoteLockdownClient) else self.SERVICE_NAME
+            service = self.lockdown.start_service(SERVICE_NAME)
+        self.service = service
         self.packet_num = 0
 
     def stop_session(self):
@@ -145,6 +152,8 @@ class AFCClient(object):
         self.service.close()
 
     def dispatch_packet(self, operation, data, this_length=0):
+        if isinstance(data, str):
+            data = data.encode('utf-8')
         afcpack = Container(magic=AFCMAGIC,
                             entire_length=40 + len(data),
                             this_length=40 + len(data),
@@ -154,8 +163,6 @@ class AFCClient(object):
             afcpack.this_length = this_length
         header = AFCPacket.build(afcpack)
         self.packet_num += 1
-        if PY3 and isinstance(data, str):
-            data = data.encode('utf-8')
         self.service.sock.send(header + data)
 
     def receive_data(self):
@@ -181,9 +188,6 @@ class AFCClient(object):
             return self.receive_data()
         except Exception as E:
             print(E)
-            self.lockdown = LockdownClient()
-            self.service = self.lockdown.start_service(self.serviceName)
-            return self.do_operation(opcode, data)
 
     def list_to_dict(self, d):
         if PY3:
@@ -282,7 +286,7 @@ class AFCClient(object):
         return status
 
     def file_read(self, handle, sz):
-        MAXIMUM_READ_SIZE = 1 << 16
+        MAXIMUM_READ_SIZE = 1 << 26
         data = ""
         if PY3:
             data = b""
@@ -297,9 +301,6 @@ class AFCClient(object):
             except:
                 import traceback
                 traceback.print_exc()
-                self.lockdown = LockdownClient()
-                self.service = self.lockdown.start_service("com.apple.afc")
-                return self.file_read(handle, sz)
 
             if s != AFC_E_SUCCESS:
                 break
@@ -308,8 +309,9 @@ class AFCClient(object):
         return data
 
     def file_write(self, handle, data):
-        MAXIMUM_WRITE_SIZE = 1 << 15
+        MAXIMUM_WRITE_SIZE = 1 << 26
         hh = struct.pack("<Q", handle)
+        _len = len(data)
         segments = int(len(data) / MAXIMUM_WRITE_SIZE)
         try:
             for i in range(segments):
@@ -320,15 +322,15 @@ class AFCClient(object):
                 if s != AFC_E_SUCCESS:
                     self.logger.error("file_write error: %d", s)
                     break
+                print(f'total: {_len / 1024 / 1024} MB write: {(i + 1) * MAXIMUM_WRITE_SIZE / 1024 / 1024} MB')
             if len(data) % MAXIMUM_WRITE_SIZE:
                 self.dispatch_packet(AFC_OP_WRITE,
                                      hh + data[segments * MAXIMUM_WRITE_SIZE:],
                                      this_length=48)
                 s, d = self.receive_data()
         except:
-            self.lockdown = LockdownClient()
-            self.service = self.lockdown.start_service(self.serviceName)
-            self.file_write(handle, data)
+            import traceback
+            traceback.print_exc()
         return s
 
     def get_file_contents(self, filename):
@@ -551,11 +553,15 @@ class AFCShell(Cmd):
 
 class AFC2Client(AFCClient):
     def __init__(self, lockdown=None, udid=None, logger=None):
-        super(AFC2Client, self).__init__(lockdown, serviceName="com.apple.afc2", udid=udid)
+        super(AFC2Client, self).__init__(lockdown, serviceName="com.apple.afc2", udid=udid, logger=logger)
 
 
 class AFCCrashLog(AFCClient):
+    SERVICE_NAME = 'com.apple.crashreportcopymobile'
+    RSD_SERVICE_NAME = 'com.apple.crashreportcopymobile.shim.remote'
+
     def __init__(self, lockdown=None, udid=None, logger=None):
-        super(AFCCrashLog, self).__init__(lockdown, serviceName="com.apple.crashreportcopymobile", udid=udid)
-
-
+        self.lockdown = lockdown or LockdownClient(udid=udid)
+        SERVICE_NAME = self.RSD_SERVICE_NAME if isinstance(self.lockdown,
+                                                           RemoteLockdownClient) else self.SERVICE_NAME
+        super(AFCCrashLog, self).__init__(lockdown, serviceName=SERVICE_NAME, udid=udid, logger=logger)
