@@ -5,9 +5,13 @@ from ..util.lockdown import LockdownClient
 
 
 class TestManagerdLockdown(DTXServer):
-    def __init__(self, lockdown=None, udid=None,network=None):
+    SERVICE_NAME = 'com.apple.testmanagerd.lockdown.secure'
+    OLD_SERVICE_NAME = 'com.apple.testmanagerd.lockdown'
+    RSD_SERVICE_NAME = 'com.apple.dt.testmanagerd.remote'
+
+    def __init__(self, lockdown=None, udid=None, network=None):
         super().__init__()
-        self.lockdown = lockdown or LockdownClient(udid=udid,network=network)
+        self.lockdown = lockdown or LockdownClient(udid=udid, network=network)
 
     def init(self, cli=None):
         if not cli:
